package com.bonus.canteen.core.supply.service;

import java.util.List;
import com.bonus.canteen.core.supply.domain.SupplyWarehouseFetchUser;

/**
 * 仓库绑定档口领料人Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface ISupplyWarehouseFetchUserService {
    /**
     * 查询仓库绑定档口领料人
     * 
     * @param id 仓库绑定档口领料人主键
     * @return 仓库绑定档口领料人
     */
    public SupplyWarehouseFetchUser selectSupplyWarehouseFetchUserById(Long id);

    /**
     * 查询仓库绑定档口领料人列表
     * 
     * @param supplyWarehouseFetchUser 仓库绑定档口领料人
     * @return 仓库绑定档口领料人集合
     */
    public List<SupplyWarehouseFetchUser> selectSupplyWarehouseFetchUserList(SupplyWarehouseFetchUser supplyWarehouseFetchUser);

    /**
     * 新增仓库绑定档口领料人
     * 
     * @param supplyWarehouseFetchUser 仓库绑定档口领料人
     * @return 结果
     */
    public int insertSupplyWarehouseFetchUser(SupplyWarehouseFetchUser supplyWarehouseFetchUser);

    /**
     * 修改仓库绑定档口领料人
     * 
     * @param supplyWarehouseFetchUser 仓库绑定档口领料人
     * @return 结果
     */
    public int updateSupplyWarehouseFetchUser(SupplyWarehouseFetchUser supplyWarehouseFetchUser);

    /**
     * 批量删除仓库绑定档口领料人
     * 
     * @param ids 需要删除的仓库绑定档口领料人主键集合
     * @return 结果
     */
    public int deleteSupplyWarehouseFetchUserByIds(Long[] ids);

    /**
     * 删除仓库绑定档口领料人信息
     * 
     * @param id 仓库绑定档口领料人主键
     * @return 结果
     */
    public int deleteSupplyWarehouseFetchUserById(Long id);
}
