package com.bonus.canteen.core.supply.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supply.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supply.domain.SupplyWarehouseFetchUser;
import com.bonus.canteen.core.supply.service.ISupplyWarehouseFetchUserService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 仓库绑定档口领料人Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "仓库绑定档口领料人接口")
@RestController
@RequestMapping("/supply_warehouse_fetch_user")
public class SupplyWarehouseFetchUserController extends BaseController {
    @Autowired
    private ISupplyWarehouseFetchUserService supplyWarehouseFetchUserService;

    /**
     * 查询仓库绑定档口领料人列表
     */
    @ApiOperation(value = "查询仓库绑定档口领料人列表")
    //@RequiresPermissions("supply:user:list")
    @GetMapping("/list")
    public TableDataInfo list(SupplyWarehouseFetchUser supplyWarehouseFetchUser) {
        startPage();
        List<SupplyWarehouseFetchUser> list = supplyWarehouseFetchUserService.selectSupplyWarehouseFetchUserList(supplyWarehouseFetchUser);
        return getDataTable(list);
    }

    /**
     * 导出仓库绑定档口领料人列表
     */
    @ApiOperation(value = "导出仓库绑定档口领料人列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:user:export")
    @SysLog(title = "仓库绑定档口领料人", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出仓库绑定档口领料人")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupplyWarehouseFetchUser supplyWarehouseFetchUser) {
        List<SupplyWarehouseFetchUser> list = supplyWarehouseFetchUserService.selectSupplyWarehouseFetchUserList(supplyWarehouseFetchUser);
        ExcelUtil<SupplyWarehouseFetchUser> util = new ExcelUtil<SupplyWarehouseFetchUser>(SupplyWarehouseFetchUser.class);
        util.exportExcel(response, list, "仓库绑定档口领料人数据");
    }

    /**
     * 获取仓库绑定档口领料人详细信息
     */
    @ApiOperation(value = "获取仓库绑定档口领料人详细信息")
    //@RequiresPermissions("supply:user:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(supplyWarehouseFetchUserService.selectSupplyWarehouseFetchUserById(id));
    }

    /**
     * 新增仓库绑定档口领料人
     */
    @ApiOperation(value = "新增仓库绑定档口领料人")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:user:add")
    @SysLog(title = "仓库绑定档口领料人", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增仓库绑定档口领料人")
    @PostMapping
    public AjaxResult add(@RequestBody SupplyWarehouseFetchUser supplyWarehouseFetchUser) {
        try {
            return toAjax(supplyWarehouseFetchUserService.insertSupplyWarehouseFetchUser(supplyWarehouseFetchUser));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改仓库绑定档口领料人
     */
    @ApiOperation(value = "修改仓库绑定档口领料人")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:user:edit")
    @SysLog(title = "仓库绑定档口领料人", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改仓库绑定档口领料人")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupplyWarehouseFetchUser supplyWarehouseFetchUser) {
        try {
            return toAjax(supplyWarehouseFetchUserService.updateSupplyWarehouseFetchUser(supplyWarehouseFetchUser));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除仓库绑定档口领料人
     */
    @ApiOperation(value = "删除仓库绑定档口领料人")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:user:remove")
    @SysLog(title = "仓库绑定档口领料人", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除仓库绑定档口领料人")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(supplyWarehouseFetchUserService.deleteSupplyWarehouseFetchUserByIds(ids));
    }
}
